@@ -1,7 +1,7 @@
 /************************************************************************
  * ifchk.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2015 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2016 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.0.1                                     *
+ * Version:         1.0.2                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -498,66 +498,11 @@ int main( int argc, char **argv )
      }
 
     /*
-     * Initialize our POSIX signal set, newMask, to the
-     * empty set. Once initialized, we then add SIGINT,
-     * SIGTERM, SIGUSR1, and SIGUSR2 to newMask.
+     * Call sigsetInit() to initialize our POSIX signal set,
+     * newMask. In doing so, we add SIGINT, SIGTERM, SIGUSR1
+     * and SIGUSR2.
      */
-    if( sigemptyset( &newMask ) != 0 )
-    {
-        errHandler( "ERROR: sigemptyset(): could not clear signal set: %s\n",
-                                                            strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Add SIGINT to newMask.
-     */
-    if( sigaddset( &newMask, SIGINT ) != 0 )
-    {
-        errHandler( "ERROR: sigaddset(): could not add SIGINT to signal set: %s\n",
-                                                                  strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Add SIGTERM to newMask.
-     */
-    if( sigaddset( &newMask, SIGTERM ) != 0 )
-    {
-        errHandler( "ERROR: sigaddset(): could not add SIGTERM to signal set: %s\n",
-                                                                   strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Add SIGUSR1 to newMask.
-     */
-    if( sigaddset( &newMask, SIGUSR1 ) != 0 )
-    {
-        errHandler( "ERROR: sigaddset(): could not add SIGUSR1 to signal set: %s\n",
-                                                                   strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Add SIGUSR2 to newMask.
-     */
-    if( sigaddset( &newMask, SIGUSR2 ) != 0 )
-    {
-        errHandler( "ERROR: sigaddset(): could not add SIGUSR2 to signal set: %s\n",
-                                                                   strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Block the four signals in newMask.
-     */
-    if( sigprocmask( SIG_BLOCK, &newMask, NULL ) != 0 )
-    {
-        errHandler( "ERROR: sigprocmask(): could not modify signal mask: %s\n",
-                                                              strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
+    newMask = sigsetInit();
 
     /*
      * Create a POSIX interval timer to send SIGUSR1 to ourselves.
