@@ -1,7 +1,7 @@
 /************************************************************************
  * linux.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2015 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2016 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous   *
  *                  mode detection and handling.               *
  *                                                             *
- * Version:         1.0.1                                      *
+ * Version:         1.0.2                                      *
  *                                                             *
  * ----------------------------------------------------------- *
  *                                                             *
@@ -136,8 +136,8 @@ int ifStat( void )
             return (-1);
          }
 
-        if( ( writeLog( LOG_INFO, "interface status: dump to stdout initiated by user %s\n",
-                                                                      pw -> pw_name ) ) != 0 )
+        if( ( writeLog( LOG_INFO, "interface status: dump initiated by user %s\n",
+                                                            pw -> pw_name ) ) != 0 )
         {
             return (-1);
          }
@@ -426,8 +426,8 @@ int ifMetric( struct ifList *list )
     /*
      * Log that a metrics dump was invoked.
      */
-    if( ( writeLog( LOG_INFO, "interface metrics: dump to stdout initiated by user %s\n",
-                                                                   pw -> pw_name ) ) != 0 )
+    if( ( writeLog( LOG_INFO, "interface metrics: dump initiated by user %s\n",
+                                                         pw -> pw_name ) ) != 0 )
     {
         return (-1);
      }
